//////////////////////////////////////////////////////////////////////////////
//
// 		  Copyright (C) 1996,1997  Matthew Doar  doar@pobox.com
// 
// Permission to use, copy, and distribute this software and its documentation 
// for any purpose with or without fee is hereby granted, provided that the 
// above copyright notice appears with all copies and that both that copyright 
// notice and this permission notice appear in supporting documentation. 
// 
// Permission to modify the software is granted, but not the right to 
// distribute the modified code. Modifications are to be distributed as 
// patches to the released version. 
// 
// This software is provided "as is" without express or implied warranty. 
//
//////////////////////////////////////////////////////////////////////////////

// tiers.cc

#ifndef _TIERS_HH
#include "tiers.hh"
#endif

// 
// Global Variable Declarations
//
// Defined in tiers_config.cc

// Type of output produced by the model, e.g. Model::GENERIC, Model::GNUPLOT
Model::OpType OP_TYPE;

// If set, TIERS_VERBOSE causes the output to contain the
// parameters used to generate the model and helpful headings
// If undefined, the output is a simple list of nodes and edges
bool TIERS_VERBOSE;

// If set, TIERS_LABEL_XXX causes the output to contain a label for
// each of the nodes of type XXX
bool TIERS_LABEL_WAN;
bool TIERS_LABEL_MAN;
bool TIERS_LABEL_LAN;


// If defined as true, the operation of the model is more verbose
// If undefined, the model should run with no debugging output
bool TIERS_DEBUG;

// If defined as true, then an undirected list of edges is produced in the 
// output, i.e. the edges (i,j) and (j,i) only appear once in the output
// Note that all LAN edges are assumed bidirectional
bool REMOVE_DUP_EDGES;

// Set these true to apply proxmity tests to nodes in each network type
bool PROXIMITY_TEST_WAN;
bool PROXIMITY_TEST_MAN;
bool PROXIMITY_TEST_LAN;

// The size of a unit in WAN, MAN and LAN grids
// e.g. 1000km, 1km, 1m would be best, but the current values fit with 
// typical int sizes
unsigned long int WAN_SCALE;
unsigned long int MAN_SCALE;
unsigned long int LAN_SCALE;	

// GRID is the size of the square grid on which points are placed
unsigned long int GRID;

// The comment character for output
char COM;


//
// GNUPLOT variables
//

// The output directory for results from gnuplot
char *title;

// The title for results from gnuplot
char *outputdir;

// Create a unique identifier for each model
long int ModelId;

// Forward declaration
unsigned long int max(unsigned long int A, unsigned long int B);

// end of file


